@@ -597,7 +597,9 @@ class Pipeline:
 
         self.context = PipelineContext()
         self.context.stop_on_exception = self.stop_on_exception
+
         for pipeline_store in self.stores:
+            logger.info(f"Adding store {pipeline_store.name}")
             self.context.add_store(pipeline_store.name, pipeline_store.store)
 
         self.context.statistics = PipelineStatistics()
@@ -621,9 +623,11 @@ class Pipeline:
 
             if document:
 
+                document.source = initial_source_metadata
                 if self.apply_lineage:
-                    document.source = initial_source_metadata
                     document.source.lineage_document_uuid = lineage_document_uuid
+                else:
+                    document.source.lineage_document_uuid = None
 
                 if self.sink:
                     logger.info(f"Writing to sink {self.sink.get_name()}")
@@ -659,7 +663,7 @@ class Pipeline:
         return self.context
 
     @staticmethod
-    def from_store(store: DocumentStore, subscription=None):
+    def from_store(store: DocumentStore, subscription=None, *args, **kwargs):
         """
         Build a new pipeline with the input documents from a document store
 
@@ -667,10 +671,10 @@ class Pipeline:
         :param subscription:str The subscription query to use
         :return: A new instance of a pipeline
         """
-        return Pipeline(DocumentStoreConnector(store, subscription))
+        return Pipeline(DocumentStoreConnector(store, subscription), *args, **kwargs)
 
     @staticmethod
-    def from_url(url, headers=None):
+    def from_url(url, headers=None, *args, **kwargs):
         """
         Build a new pipeline with the input being a document created from the given URL
 
@@ -678,20 +682,20 @@ class Pipeline:
         :param headers: A dictionary of headers
         :return: A new instance of a pipeline
         """
-        return Pipeline(Document.from_url(url, headers))
+        return Pipeline(Document.from_url(url, headers), *args, **kwargs)
 
     @staticmethod
-    def from_file(file_path: str) -> Pipeline:
+    def from_file(file_path: str, *args, **kwargs) -> Pipeline:
         """
         Create a new pipeline using a file path as a source
         :param file_path: The path to the file
         :return: A new pipeline
         :rtype: Pipeline
         """
-        return Pipeline(Document.from_file(file_path))
+        return Pipeline(Document.from_file(file_path), *args, **kwargs)
 
     @staticmethod
-    def from_text(text: str) -> Pipeline:
+    def from_text(text: str, *args, **kwargs) -> Pipeline:
         """
         Build a new pipeline and provide text as the basic to create a document
 
@@ -699,7 +703,7 @@ class Pipeline:
         :return: A new pipeline
         :rtype: Pipeline
         """
-        return Pipeline(Document.from_text(text))
+        return Pipeline(Document.from_text(text), *args, **kwargs)
 
     @staticmethod
     def from_folder(folder_path: str, filename_filter: str = "*", recursive: bool = False, relative: bool = False,
@@ -717,7 +721,7 @@ class Pipeline:
         :rtype: Pipeline
         """
         return Pipeline(FolderConnector(folder_path, filename_filter, recursive=recursive, relative=relative,
-                                        caller_path=caller_path, unpack=unpack))
+                                        caller_path=caller_path, unpack=unpack), *args, **kwargs)
 
 
 class PipelineStatistics:
